import { __awaiter, __decorate, __metadata } from 'tslib';
import { Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { LabeledComponent, JSONUtils, LabelProperties, propDescription, PropertyCategories, BaseUIComponent, StyleProperties, CoreService, CoreModule } from '@ngx-dynamic-components/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { NgSelectModule } from '@ng-select/ng-select';
import { setTheme } from 'ngx-bootstrap/utils';
import { TabsModule } from 'ngx-bootstrap/tabs';

const packageName = 'bootstrap';

let SelectComponent = class SelectComponent extends LabeledComponent {
    onSelect() {
        return __awaiter(this, void 0, void 0, function* () {
            this.changedDataModel.emit(this.dataModel);
            this.emitEvent(this.properties.onSelect);
        });
    }
    get selectStyles() {
        if (this.properties.selectHeight) {
            return {
                height: this.properties.selectHeight
            };
        }
        return null;
    }
    get options() {
        const src = this.properties.itemsSource;
        if (Array.isArray(src)) {
            return src;
        }
        if (typeof src === 'string' && src.startsWith('$.')) {
            return JSONUtils.find(this.dataModel, src);
        }
    }
};
SelectComponent = __decorate([
    Component({
        selector: 'dc-select',
        template: `
    <div class="form-group mb-0" [fxLayout]="layout" [fxLayoutAlign]="align" [ngStyle]="itemStyles">
      <label selected *ngIf="hasLabel" [for]="id" class="my-0" [class]="properties.labelPosition"
      [fxFlex]="layout === 'row' ? properties.labelWidth : false">{{properties.label}}</label>
      <ng-select [items]="options" (change)="onSelect()" fxFlexFill [ngStyle]="selectStyles"
      [(ngModel)]="componentDataModel" bindValue="value"></ng-select>
    </div>`,
        styles: ["label.bottom,label.right{-webkit-box-ordinal-group:2;order:1}", `
    :host ::ng-deep .ng-select.ng-select-single .ng-select-container {
      height: inherit;
      min-height: 30px;
    }
  `]
    })
], SelectComponent);
class SelectProperties extends LabelProperties {
}
__decorate([
    propDescription({
        description: 'Select options or binding to dataModel.',
        example: '[{label: "One", value: 1}]',
    }),
    __metadata("design:type", Object)
], SelectProperties.prototype, "itemsSource", void 0);
__decorate([
    propDescription({
        description: 'Select height.',
        example: '30px',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "selectHeight", void 0);
__decorate([
    propDescription({
        description: 'On Select handler name.',
        example: 'onCountrySelect',
    }),
    __metadata("design:type", String)
], SelectProperties.prototype, "onSelect", void 0);
const example = {
    uiModel: `
    <flex-container fxLayout="column">
      <select onSelect="countryChanged" label="Country" labelWidth="50px" width="300px" labelPosition="left" binding="$.country">
        <option value="uk">United Kingdom</option>
        <option value="ua">Ukraine</option>
      </select>
      <select label="City" labelWidth="50px" width="300px"
        itemsSource="$.cities" labelPosition="left" binding="$.city"></select>
    </flex-container>
  `,
    dataModel: {},
    scripts: `
  def countryChanged():
    dataModel.city = null
    if dataModel.country == null:
      dataModel.cities = []
    if dataModel.country == "uk":
      dataModel.cities = [{label: "London", value: "lon"}, {label: "Liverpool", value: "liv"}]
    if dataModel.country == "ua":
      dataModel.cities = [{label: "Kyiv", value: "kyiv"}, {label: "Lviv", value: "lvi"}]
  `,
    title: 'Basic select example'
};
const selectDescriptor = {
    name: 'select',
    label: 'UI Select Input',
    packageName,
    category: "Basic" /* Basic */,
    description: 'Select component',
    itemProperties: SelectProperties,
    component: SelectComponent,
    example,
    parseUIModel(xmlRes) {
        const itemProperties = {};
        if (!xmlRes.attrs.itemsSource && xmlRes.childNodes) {
            itemProperties.itemsSource = xmlRes.childNodes.map(r => {
                return { label: r._, value: r.$.value };
            });
            xmlRes.childNodes = null;
        }
        return {
            type: 'select',
            itemProperties
        };
    },
    defaultModel: {
        type: `core:select`,
        containerProperties: {},
        itemProperties: {
            itemsSource: [
                { label: 'First option', value: '1' },
                { label: 'Second option', value: '2' }
            ],
            width: '200px',
            label: 'Select option',
            binding: '$.option'
        }
    },
    propertiesDescriptor: [
        ['selectHeight', { name: 'selectHeight', label: 'Select Height', category: PropertyCategories.Layout }],
    ]
};

let TabsComponent = class TabsComponent extends BaseUIComponent {
};
TabsComponent = __decorate([
    Component({
        selector: 'dc-tabs-ui',
        template: `
    <tabset drop-container class="tabset-fx">
      <tab *ngFor="let item of uiModel.children; let i = index" [heading]="item.containerProperties.header || 'Tab ' + (i + 1)">
      <dc-ui-selector
          (changedDataModel)="changedDataModel.emit(dataModel)"
          [uiModel]="item"
          [dataModel]="dataModel"
          ></dc-ui-selector>
      </tab>
    </tabset>
  `
    })
], TabsComponent);
class TabsProperties extends StyleProperties {
}
const example$1 = {
    title: 'Tabs group example',
    uiModel: `
  <tab-container width="100%" height="100%" margin="8px">
		<tab header="Test tab" padding="0.5rem">
			<text text-style="h1">Tab 1 static text content</text>
		</tab>
		<!--Tab should be a flex-container as well-->
    <tab header="Btn tab" padding="0.5rem" fxLayout="column" fxLayoutGap="8px">
      <text text-style="h1">Button content</text>
      <button class="btn btn-primary mr-2" on-click="button1_Click">Click</button>
      <flex-container>
        <text text-style="h4">ClickCount:</text>
        <text text-style="h4">$.clickCount</text>
      </flex-container>
		</tab>
	</tab-container>
  `,
    scripts: `
  def button1_Click():
    print("button1_Click")
    if dataModel.clickCount == null:
      dataModel.clickCount = 0
    dataModel.clickCount = dataModel.clickCount + 1
  `,
    dataModel: {}
};
const tabsDescriptor = {
    name: 'tab-container',
    label: 'Tabs container (Bootstrap)',
    packageName,
    category: "Containers" /* Containers */,
    description: 'Tabs component',
    itemProperties: TabsProperties,
    component: TabsComponent,
    example: example$1,
    parseUIModel(xmlData) {
        const children = xmlData.childNodes.map(child => {
            const { itemProperties, containerProperties } = CoreService.getPropertiesFromAttributes(child.$);
            return {
                type: 'flex-container',
                children: child.$$.map((r) => CoreService.getUIModel(CoreService.getXMLResult(r))),
                containerProperties,
                itemProperties
            };
        });
        return {
            type: `${packageName}:tab-container`,
            children
        };
    },
    defaultModel: {
        type: `${packageName}:tab-container`,
        containerProperties: {},
        itemProperties: {},
        children: [{
                type: 'flex-container',
                containerProperties: {
                    width: '100%',
                    height: '100%',
                    label: 'Tab 1',
                },
                itemProperties: {
                    children: [],
                    width: '100%',
                    height: '100%',
                }
            }, {
                type: 'flex-container',
                containerProperties: {
                    width: '100%',
                    height: '100%',
                    label: 'Tab 2',
                },
                itemProperties: {
                    children: [],
                    width: '100%',
                    height: '100%',
                }
            }]
    }
};

const COMPONENTS_LIST = [
    tabsDescriptor,
    selectDescriptor
];
// Register components.
function registerComponents() {
    COMPONENTS_LIST.forEach(component => CoreService.registerComponent(component));
}
function getCategories() {
    const categories = COMPONENTS_LIST.reduce((map, desc) => {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }, {});
    return Object.entries(categories).map(([key, val]) => {
        return {
            name: key,
            components: val,
            packageName
        };
    });
}

let BootstrapModule = class BootstrapModule {
    constructor() {
        setTheme('bs4');
        registerComponents();
    }
};
BootstrapModule = __decorate([
    NgModule({
        declarations: [SelectComponent, TabsComponent],
        imports: [
            CoreModule,
            CommonModule,
            FormsModule,
            FlexLayoutModule,
            NgSelectModule,
            TabsModule.forRoot()
        ]
    }),
    __metadata("design:paramtypes", [])
], BootstrapModule);

/*
 * Public API Surface of bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapModule, COMPONENTS_LIST, SelectComponent, TabsComponent, getCategories, SelectComponent as ɵa, SelectProperties as ɵb, example as ɵc, selectDescriptor as ɵd, TabsComponent as ɵe, TabsProperties as ɵf, example$1 as ɵg, tabsDescriptor as ɵh, packageName as ɵi };
//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map
